@@ -1,8 +1,9 @@
+from __future__ import absolute_import
 import re
 import sys
 import platform
 from .compat import integer_types, zip_longest
-from . import bson_ as bson
+from . import bson
 
 RE_PATTERN_TYPE = type(re.compile(""))
 
